/*
 * Copyright (c) 2024 ShinGeTsu Meter.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */
#pragma once

// GPOIO
#define LED_PIN 25

// ロータリーエンコーダ
#define TA_RE1 14
#define TA_RE2 15

// ボタン
#define BTN1         6
#define BTN2         7
#define BTN3         8
#define BTN4         9
#define BTN5         21    // 未使用
#define BTN6         20    // 未使用
#define BTN7         19    // 未使用
#define BTN8         18    // 未使用
#define BUTTON_SET   BTN1
#define BUTTON_COUNT BTN2
#define BUTTON_AUTO  BTN3
#define BUTTON_VIEW  BTN4

// 電源
#define VSYS_ADC_PIN   29
#define VSYS_ADC_NO    3
#define VBUS_SENSE_PIN 24

// ロータリーエンコーダ移動方向判定用
#define ROTARY_DIRECTION \
    { 0, 1, -1, 0, -1, 0, 0, 1, 1, 0, 0, -1, 0, -1, 1, 0 }

// 時間
#define SAMPLING_uS    (10 * 1000)            // サンプリング間隔(9mSぐらいが限界)
#define UPDATE_uS      (SAMPLING_uS * 50)     // LCD更新間隔
#define AUTO_SET_uS    (SAMPLING_uS * 100)    // 自動セットの待ち時間
#define BLOCK_uS       (SAMPLING_uS * 50)     // ブロック時間
#define EVENT_BLOCK_uS (10 * 1000)            // 同じイベントの連続実行を抑止する時間

// 履歴
#define TA_HIST_SIZE    100    // TA履歴サイズ
#define METER_HIST_SIZE 10     // メーター目盛履歴サイズ 大きいほど感度が良い

// TA
#define TA_MAX         6.5       // TA最大値
#define TA_MIN         0.9412    // TA最小値
#define TA_BLOCK_RANGE 0.800     // 履歴中のTA範囲がこれより大きい場合ブロック

// メーターの目盛  左端:0,0[V], セット位置:15,1[v], 右端:40,2.67[v]
#define REFV               (2.5 - 1.5)    // 計装アンプの参照電圧 = セット位置の電圧  2.5[v] - 1.5[v]
#define METER_SET          15.0           // セット位置のオフセット
#define METER_MAX          40.0           // 目盛の最大値
#define METER_BLOCK        55.0           // これより大きい場合ブロック
#define METER_BLOCK_TH     32.0           // メーター目盛履歴の平均値がこれより大きい場合ブロックしない
#define METER_AUTO_SET_MIN 2.0            // 自動セット閾値 左端
#define METER_AUTO_SET_MAX 38.0           // 自動セット閾値 右端

// 電源
#define RUNNING_LOW 4.0    // 電源電圧が4.0vより低くなると定電圧回路が2.5vを維持できなくなる
#define NOT_ENOUGH  3.8    // 電源電圧が3.8vより低くなるとAD8226が十分に増幅できなくなる

// 表示モード
typedef enum {
    VIEW_NORMAL = 0,
    VIEW_TA,
    VIEW_VOLT,
    VIEW_POWER,
} view_t;
